<?php
/**
 * Plugin Name: Catna - Woo Name Your Price and Offers
 * Plugin URI: https://villatheme.com/extensions/catna-woocommerce-name-your-price-and-offers/
 * Description: Catna - Woo Name Your Price and Offers allows customers to purchase products at their optional price matched the conditions set.
 * Version: 1.0.8
 * Author: VillaTheme
 * Author URI: https://villatheme.com
 * Text Domain: catna-woo-name-your-price-and-offers
 * Domain Path: /languages
 * Copyright 2021 - 2023 VillaTheme.com. All rights reserved.
 * Requires PHP: 7.0
 * Requires at least: 5.0
 * Tested up to: 6.2
 * WC requires at least: 5.0
 * WC tested up to: 7.5
 **/
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if ( is_plugin_active( 'catna-woocommerce-name-your-price-and-offers/catna-woocommerce-name-your-price-and-offers.php' ) ) {
	return;
}

/**
 * Class VICATNA_INIT
 */
class VICATNA_INIT {
	protected $plugin_name;
	protected $php_version, $wp_version, $wc_version;
	protected $errors;
	public function __construct() {
		$this->define();
		$this->get_errors();
		//compatible with 'High-Performance order storage (COT)'
		add_action( 'before_woocommerce_init', array( $this, 'before_woocommerce_init' ) );
		if ( is_array( $this->errors ) && count( $this->errors ) ) {
			add_action( 'admin_notices', array( $this, 'global_note' ) );
		} else {
			$this->includes();
		}
	}
	protected function define() {
		$this->plugin_name = 'Catna - Woo Name Your Price and Offers';
		$this->php_version = '7.0';
		$this->wp_version  = '5.0';
		$this->wc_version  = '5.0';
		define( 'VICATNA_VERSION', '1.0.8' );
		define( 'VICATNA_DIR', plugin_dir_path( __FILE__ ) );
		define( 'VICATNA_INCLUDES', VICATNA_DIR . "includes" . DIRECTORY_SEPARATOR );
		define( 'VICATNA_ADMIN', VICATNA_INCLUDES . "admin" . DIRECTORY_SEPARATOR );
		define( 'VICATNA_FRONTEND', VICATNA_INCLUDES . "frontend" . DIRECTORY_SEPARATOR );
		define( 'VICATNA_LANGUAGES', VICATNA_DIR . "languages" . DIRECTORY_SEPARATOR );
		define( 'VICATNA_TEMPLATES', VICATNA_INCLUDES . "templates" . DIRECTORY_SEPARATOR );
		$plugin_url = plugins_url( 'assets/', __FILE__ );
		define( 'VICATNA_CSS', $plugin_url . "css/" );
		define( 'VICATNA_JS', $plugin_url . "js/" );
		define( 'VICATNA_IMAGES', $plugin_url . "images/" );
		define( 'VICATNA_SUFFIX', WP_DEBUG ? '' : 'min.' );
	}
	protected function get_errors() {
		$this->errors = array();
		if ( ! version_compare( phpversion(), $this->php_version, '>=' ) ) {
			$this->errors[] = sprintf( '%s %s %s %s',
				esc_html__( 'Please update PHP version at least', 'catna-woo-name-your-price-and-offers' ), $this->php_version,
				esc_html__( 'to use', 'catna-woo-name-your-price-and-offers' ), $this->plugin_name
			);
		}
		global $wp_version;
		if ( ! version_compare( $wp_version, $this->wp_version, '>=' ) ) {
			$this->errors[] = sprintf( '%s %s %s %s',
				esc_html__( 'Please update WordPress version at least', 'catna-woo-name-your-price-and-offers' ), $this->wp_version,
				esc_html__( 'to use', 'catna-woo-name-your-price-and-offers' ), $this->plugin_name
			);
		}
		if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
			$this->errors[] = sprintf( '%s %s',
				esc_html__( 'Please install and activate WooCommerce to use', 'catna-woo-name-your-price-and-offers' ), $this->plugin_name
			);
		}
		$wc_version = get_option( 'woocommerce_version' );
		if ( ! ( $wc_version && version_compare( $wc_version, $this->wc_version, '>=' ) ) ) {
			$this->errors[] = sprintf( '%s %s %s %s',
				esc_html__( 'Please update WooCommerce version at least', 'catna-woo-name-your-price-and-offers' ), $this->wc_version,
				esc_html__( 'to use', 'catna-woo-name-your-price-and-offers' ), $this->plugin_name
			);
		}
	}
	protected function includes() {
		$files = array(
			VICATNA_INCLUDES . "functions.php",
			VICATNA_INCLUDES . 'support.php',
			VICATNA_INCLUDES . 'data.php',
			VICATNA_INCLUDES . 'rule.php',
		);
		foreach ( $files as $file ) {
			if ( file_exists( $file ) ) {
				require_once $file;
			}
		}
		villatheme_include_folder( VICATNA_ADMIN, 'VICATNA_Admin_' );
		if ( ! is_admin() || wp_doing_ajax() ) {
			villatheme_include_folder( VICATNA_FRONTEND, 'VICATNA_Frontend_' );
		}
	}
	/**
	 * Notify if has notices
	 */
	public function global_note() {
		if ( count( $this->errors ) ) {
			foreach ( $this->errors as $error ) {
				printf( '<div id="message" class="error"><p><strong>%s</strong></p></div>', esc_html( $error ) );
			}
		}
	}
	public function before_woocommerce_init() {
		if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	}
}

new VICATNA_INIT();